@@ -630,6 +630,8 @@ const CURRENCIES: &[UnitTuple] = &[
 	("AU$", "AU$", "AUD", ""),
 	("HK$", "HK$", "HKD", ""),
 	("NZ$", "NZ$", "NZD", ""),
+	("zł", "zł", "PLN", ""), // the local abbreviation for PLN, see https://en.wikipedia.org/wiki/Polish_z%C5%82oty
+	("zl", "zl", "PLN", ""),
 ];
 
 // from https://en.wikipedia.org/wiki/ISO_4217
